[llvm-commits] CVS: llvm/include/llvm/Analysis/DSGraph.h

Chris Lattner lattner at cs.uiuc.edu
Sun Nov 3 15:28:00 PST 2002


Changes in directory llvm/include/llvm/Analysis:

DSGraph.h updated: 1.24 -> 1.25

---
Log message:

Rename ValueMap to ScalarMap


---
Diffs of the changes:

Index: llvm/include/llvm/Analysis/DSGraph.h
diff -u llvm/include/llvm/Analysis/DSGraph.h:1.24 llvm/include/llvm/Analysis/DSGraph.h:1.25
--- llvm/include/llvm/Analysis/DSGraph.h:1.24	Thu Oct 31 15:24:10 2002
+++ llvm/include/llvm/Analysis/DSGraph.h	Sun Nov  3 15:27:46 2002
@@ -16,7 +16,7 @@
   Function *Func;
   std::vector<DSNode*> Nodes;
   DSNodeHandle RetNode;                          // Node that gets returned...
-  std::map<Value*, DSNodeHandle> ValueMap;
+  std::map<Value*, DSNodeHandle> ScalarMap;
 
 #if 0
   // GlobalsGraph -- Reference to the common graph of globally visible objects.
@@ -58,11 +58,11 @@
   ///
   void addNode(DSNode *N) { Nodes.push_back(N); }
 
   /// getValueMap - Get a map that describes what the nodes the scalars in this
   /// function point to...
   ///
-  std::map<Value*, DSNodeHandle> &getValueMap() { return ValueMap; }
-  const std::map<Value*, DSNodeHandle> &getValueMap() const { return ValueMap;}
+  std::map<Value*, DSNodeHandle> &getScalarMap() { return ScalarMap; }
+  const std::map<Value*, DSNodeHandle> &getScalarMap() const {return ScalarMap;}
 
   std::vector<DSCallSite> &getFunctionCalls() {
     return FunctionCalls;
@@ -74,7 +74,7 @@
   /// getNodeForValue - Given a value that is used or defined in the body of the
   /// current function, return the DSNode that it points to.
   ///
-  DSNodeHandle &getNodeForValue(Value *V) { return ValueMap[V]; }
+  DSNodeHandle &getNodeForValue(Value *V) { return ScalarMap[V]; }
 
   const DSNodeHandle &getRetNode() const { return RetNode; }
         DSNodeHandle &getRetNode()       { return RetNode; }
@@ -119,10 +119,10 @@
   void removeDeadNodes(bool KeepAllGlobals = false, bool KeepCalls = true);
 
   // cloneInto - Clone the specified DSGraph into the current graph, returning
   // the Return node of the graph.  The translated ValueMap for the old function
   // is filled into the OldValMap member.
   // If StripScalars (StripAllocas) is set to true, Scalar (Alloca) markers
   // are removed from the graph as the graph is being cloned.
   //
   DSNodeHandle cloneInto(const DSGraph &G,
                          std::map<Value*, DSNodeHandle> &OldValMap,
@@ -135,8 +135,8 @@
   // 
   DSNode* cloneGlobalInto(const DSNode* GNode);
   DSNode* cloneGlobalInto(GlobalValue* GV) {
-    assert(!GV || (((DSGraph*) GlobalsGraph)->ValueMap[GV] != 0));
-    return GV? cloneGlobalInto(((DSGraph*) GlobalsGraph)->ValueMap[GV]) : 0;
+    assert(!GV || (((DSGraph*) GlobalsGraph)->ScalarMap[GV] != 0));
+    return GV? cloneGlobalInto(((DSGraph*) GlobalsGraph)->ScalarMap[GV]) : 0;
   }
 #endif
 
@@ -58,11 +58,11 @@
   void addNode(DSNode *N) { Nodes.push_back(N); }
 
-  /// getValueMap - Get a map that describes what the nodes the scalars in this
+  /// getScalarMap - Get a map that describes what the nodes the scalars in this
   /// function point to...
   ///
@@ -119,10 +119,10 @@
 
   // cloneInto - Clone the specified DSGraph into the current graph, returning
-  // the Return node of the graph.  The translated ValueMap for the old function
-  // is filled into the OldValMap member.
-  // If StripScalars (StripAllocas) is set to true, Scalar (Alloca) markers
-  // are removed from the graph as the graph is being cloned.
+  // the Return node of the graph.  The translated ScalarMap for the old
+  // function is filled into the OldValMap member.  If StripScalars
+  // (StripAllocas) is set to true, Scalar (Alloca) markers are removed from the
+  // graph as the graph is being cloned.
   //
   DSNodeHandle cloneInto(const DSGraph &G,





More information about the llvm-commits mailing list